@@ -9,6 +9,9 @@ def create_customerpayment(customerpayment):
   authenticate()
   post_url = f"{BASE_URL}"
   result = post(post_url, HEADERS, json.dumps(customerpayment))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = post(post_url, HEADERS, json.dumps(customerpayment))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to create customerpayment. Result: {result}")
   return result
@@ -18,6 +21,9 @@ def update_customerpayment(customerpayment_id, customerpayment):
   authenticate()
   post_url = f"{BASE_URL}/{customerpayment_id}"
   result = put(post_url, HEADERS, json.dumps(customerpayment))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = put(post_url, HEADERS, json.dumps(customerpayment))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update customerpayment. Result: {result}")
   return result
@@ -27,6 +33,9 @@ def get_customerpayment(customerpayment_id):
   authenticate()
   post_url = f"{BASE_URL}/{customerpayment_id}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve customerpayment. Result: {result}")
   return result
@@ -74,6 +83,9 @@ def search_customerpayments(customer_name=None,
   for name, value in kwargs.items():
     post_url = f"{post_url}&{name}={value}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve customerpayments. Result: {result}")
   return result
