@@ -9,6 +9,9 @@ def create_invoice(invoice):
   authenticate()
   post_url = f"{BASE_URL}"
   result = post(post_url, HEADERS, json.dumps(invoice))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = post(post_url, HEADERS, json.dumps(invoice))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to create invoice. Result: {result}")
   return result
@@ -18,6 +21,9 @@ def update_invoice(invoice_id, invoice):
   authenticate()
   post_url = f"{BASE_URL}/{invoice_id}"
   result = put(post_url, HEADERS, json.dumps(invoice))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = put(post_url, HEADERS, json.dumps(invoice))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update invoice. Result: {result}")
   return result
@@ -27,6 +33,9 @@ def get_invoice(invoice_id):
   authenticate()
   post_url = f"{BASE_URL}/{invoice_id}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve invoice. Result: {result}")
   return result
@@ -89,6 +98,9 @@ def search_invoices(invoice_number=None,
   for name, value in kwargs.items():
     post_url = f"{post_url}&{name}={value}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve invoices. Result: {result}")
   return result
